@@ -1,6 +1,6 @@
 /*  xfce4-kbdleds-plugin - panel plugin for keyboard LEDs
  *
- *  Copyright (c) 2011 Oleg Voronin <oco@newmail.ru>
+ *  Copyright (c) 2011-2019 OCo <oco2000@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,18 +33,23 @@ typedef struct
     GtkWidget       *label;
 
     /* kbdleds settings */
-    gchar           *setting1;
-    gint             setting2;
-    gboolean         setting3;
+    GdkRGBA          foreground_color;
+    GdkRGBA          background_color;
 }
 kbdledsPlugin;
 
-
+/* default settings */
+static gchar* DEFAULT_FOREGROUND_COLOR = "#000000";
+static gchar* DEFAULT_BACKGROUND_COLOR = "#00FF00";
 
 void
 kbdleds_save (XfcePanelPlugin *plugin,
              kbdledsPlugin    *kbdleds);
 
+void show_error(gchar *message);
+
+void refresh();
+
 G_END_DECLS
 
 #endif /* !__KBDLEDS_H__ */
